==> kea-docs-2.0.2-1-aarch64.pkg.tar.xz: usr/share/doc/kea/devel/dir_e35cb9067eb8c69a7d87e0acd94a7e97.js <==
var dir_e35cb9067eb8c69a7d87e0acd94a7e97 =
[
    [ "base_stamped_element.cc", "d7/df2/base__stamped__element_8cc.html", null ],
    [ "base_stamped_element.h", "df/d2b/base__stamped__element_8h.html", [
      [ "isc::data::BaseStampedElement", "d2/dfd/classisc_1_1data_1_1BaseStampedElement.html", "d2/dfd/classisc_1_1data_1_1BaseStampedElement" ]
    ] ],
    [ "cfg_to_element.h", "d7/d2d/cfg__to__element_8h.html", [
      [ "isc::data::CfgToElement", "da/d9e/structisc_1_1data_1_1CfgToElement.html", "da/d9e/structisc_1_1data_1_1CfgToElement" ],
      [ "isc::ToElementError", "df/d72/classisc_1_1ToElementError.html", "df/d72/classisc_1_1ToElementError" ]
    ] ],
    [ "command_interpreter.cc", "d7/d88/command__interpreter_8cc.html", "d7/d88/command__interpreter_8cc" ],
    [ "command_interpreter.h", "d3/db0/command__interpreter_8h.html", "d3/db0/command__interpreter_8h" ],
    [ "data.cc", "d4/d05/data_8cc.html", "d4/d05/data_8cc" ],
    [ "data.h", "d2/dbd/data_8h.html", "d2/dbd/data_8h" ],
    [ "dhcp_config_error.h", "d7/d7f/dhcp__config__error_8h.html", [
      [ "isc::ConfigError", "de/d97/classisc_1_1ConfigError.html", "de/d97/classisc_1_1ConfigError" ],
      [ "isc::dhcp::DhcpConfigError", "dc/dc3/classisc_1_1dhcp_1_1DhcpConfigError.html", "dc/dc3/classisc_1_1dhcp_1_1DhcpConfigError" ],
      [ "isc::ParseError", "d2/dd2/classisc_1_1ParseError.html", "d2/dd2/classisc_1_1ParseError" ]
    ] ],
    [ "element_value.h", "df/df0/element__value_8h.html", [
      [ "isc::data::ElementValue< T >", "d4/d50/classisc_1_1data_1_1ElementValue.html", "d4/d50/classisc_1_1data_1_1ElementValue" ],
      [ "isc::data::ElementValue< asiolink::IOAddress >", "d8/d75/classisc_1_1data_1_1ElementValue_3_01asiolink_1_1IOAddress_01_4.html", "d8/d75/classisc_1_1data_1_1ElementValue_3_01asiolink_1_1IOAddress_01_4" ],
      [ "isc::data::ElementValue< bool >", "d1/dfa/classisc_1_1data_1_1ElementValue_3_01bool_01_4.html", "d1/dfa/classisc_1_1data_1_1ElementValue_3_01bool_01_4" ],
      [ "isc::data::ElementValue< double >", "d8/d51/classisc_1_1data_1_1ElementValue_3_01double_01_4.html", "d8/d51/classisc_1_1data_1_1ElementValue_3_01double_01_4" ],
      [ "isc::data::ElementValue< std::string >", "d4/dd9/classisc_1_1data_1_1ElementValue_3_01std_1_1string_01_4.html", "d4/dd9/classisc_1_1data_1_1ElementValue_3_01std_1_1string_01_4" ]
    ] ],
    [ "json_feed.cc", "dd/de4/json__feed_8cc.html", null ],
    [ "json_feed.h", "de/d0f/json__feed_8h.html", "de/d0f/json__feed_8h" ],
    [ "server_tag.cc", "d4/d22/server__tag_8cc.html", "d4/d22/server__tag_8cc" ],
    [ "server_tag.h", "d8/d9f/server__tag_8h.html", "d8/d9f/server__tag_8h" ],
    [ "lib/cc/simple_parser.cc", "d0/df9/lib_2cc_2simple__parser_8cc.html", null ],
    [ "lib/cc/simple_parser.h", "dd/d27/lib_2cc_2simple__parser_8h.html", "dd/d27/lib_2cc_2simple__parser_8h" ],
    [ "stamped_element.cc", "d9/db9/stamped__element_8cc.html", null ],
    [ "stamped_element.h", "d4/d25/stamped__element_8h.html", [
      [ "isc::data::StampedElement", "d3/d46/classisc_1_1data_1_1StampedElement.html", "d3/d46/classisc_1_1data_1_1StampedElement" ]
    ] ],
    [ "stamped_value.cc", "d0/ddb/stamped__value_8cc.html", null ],
    [ "stamped_value.h", "da/d16/stamped__value_8h.html", "da/d16/stamped__value_8h" ],
    [ "user_context.cc", "de/dbc/user__context_8cc.html", null ],
    [ "user_context.h", "dc/d58/user__context_8h.html", [
      [ "isc::data::UserContext", "d9/db0/structisc_1_1data_1_1UserContext.html", "d9/db0/structisc_1_1data_1_1UserContext" ]
    ] ]
];

==> kea-docs-2.2.0-3-aarch64.pkg.tar.xz: usr/share/doc/kea/devel/dir_e35cb9067eb8c69a7d87e0acd94a7e97.js <==
var dir_e35cb9067eb8c69a7d87e0acd94a7e97 =
[
    [ "base_stamped_element.cc", "d7/df2/base__stamped__element_8cc.html", null ],
    [ "base_stamped_element.h", "df/d2b/base__stamped__element_8h.html", "df/d2b/base__stamped__element_8h" ],
    [ "cfg_to_element.h", "d7/d2d/cfg__to__element_8h.html", "d7/d2d/cfg__to__element_8h" ],
    [ "command_interpreter.cc", "d7/d88/command__interpreter_8cc.html", "d7/d88/command__interpreter_8cc" ],
    [ "command_interpreter.h", "d3/db0/command__interpreter_8h.html", "d3/db0/command__interpreter_8h" ],
    [ "data.cc", "d4/d05/data_8cc.html", "d4/d05/data_8cc" ],
    [ "data.h", "d2/dbd/data_8h.html", "d2/dbd/data_8h" ],
    [ "dhcp_config_error.h", "d7/d7f/dhcp__config__error_8h.html", "d7/d7f/dhcp__config__error_8h" ],
    [ "element_value.h", "df/df0/element__value_8h.html", "df/df0/element__value_8h" ],
    [ "json_feed.cc", "dd/de4/json__feed_8cc.html", null ],
    [ "json_feed.h", "de/d0f/json__feed_8h.html", "de/d0f/json__feed_8h" ],
    [ "server_tag.cc", "d4/d22/server__tag_8cc.html", "d4/d22/server__tag_8cc" ],
    [ "server_tag.h", "d8/d9f/server__tag_8h.html", "d8/d9f/server__tag_8h" ],
    [ "lib/cc/simple_parser.cc", "d0/df9/lib_2cc_2simple__parser_8cc.html", null ],
    [ "lib/cc/simple_parser.h", "dd/d27/lib_2cc_2simple__parser_8h.html", "dd/d27/lib_2cc_2simple__parser_8h" ],
    [ "stamped_element.cc", "d9/db9/stamped__element_8cc.html", null ],
    [ "stamped_element.h", "d4/d25/stamped__element_8h.html", "d4/d25/stamped__element_8h" ],
    [ "stamped_value.cc", "d0/ddb/stamped__value_8cc.html", null ],
    [ "stamped_value.h", "da/d16/stamped__value_8h.html", "da/d16/stamped__value_8h" ],
    [ "user_context.cc", "de/dbc/user__context_8cc.html", null ],
    [ "user_context.h", "dc/d58/user__context_8h.html", "dc/d58/user__context_8h" ]
];
